/******************************************************************************/
/* PException header file.                                                    */
/******************************************************************************/
/* This is part of the PolyKit library.                                       */
/* Copyright (C) 1998-1999 by Polycode.                                       */
/* All rights reserved.                                                       */
/*                                                                            */
/* This source, or parts thereof, may be used for free in free- and shareware */
/* programs. For commercial programs, you have to pay a fee to use it. See    */
/* the license file for more information.                                     */
/******************************************************************************/


#ifndef __PException_h
#define __PException_h

// PolyKit headers
#include "POS.h"
#include "PString.h"
#include "ImportExport.h"


/******************************************************************************/
/* PException class                                                           */
/******************************************************************************/
#if __p_os == __p_beos && __POWERPC__
#pragma export on
#endif

class _IMPEXP_PKLIB PException
{
public:
	PException(int32 error = P_ERR_ANY);
	virtual ~PException(void);

	int32 errorNum;				// The error number
};



/******************************************************************************/
/* PBoundsException class                                                     */
/******************************************************************************/
class _IMPEXP_PKLIB PBoundsException : public PException
{
public:
	PBoundsException(int32 error = P_ERR_ANY, double val = 0.0);
	virtual ~PBoundsException(void);

	double value;
};



/******************************************************************************/
/* PFileException class                                                       */
/******************************************************************************/
class _IMPEXP_PKLIB PFileException : public PException
{
public:
	PFileException(int32 error = P_FILE_ERR_FILE, PString file = "");
	virtual ~PFileException(void);

	PString fileName;
};



/******************************************************************************/
/* PKeyException class                                                        */
/******************************************************************************/
class _IMPEXP_PKLIB PKeyException : public PException
{
public:
	PKeyException(int32 error = P_ERR_ANY);
	virtual ~PKeyException(void);
};



/******************************************************************************/
/* PMemoryException class                                                     */
/******************************************************************************/
class _IMPEXP_PKLIB PMemoryException : public PException
{
public:
	PMemoryException(int32 error = P_GEN_ERR_NO_MEMORY);
	virtual ~PMemoryException(void);
};



/******************************************************************************/
/* PResourceException class                                                   */
/******************************************************************************/
class _IMPEXP_PKLIB PResourceException : public PException
{
public:
	PResourceException(int32 error = P_GEN_ERR_NO_RESOURCES);
	virtual ~PResourceException(void);
};



/******************************************************************************/
/* PSoundException class                                                      */
/******************************************************************************/
class _IMPEXP_PKLIB PSoundException : public PException
{
public:
	PSoundException(int32 error = P_ERR_ANY);
	virtual ~PSoundException(void);
};



/******************************************************************************/
/* PSystemException class                                                     */
/******************************************************************************/
class _IMPEXP_PKLIB PSystemException : public PException
{
public:
	PSystemException(int32 error = P_ERR_ANY);
	virtual ~PSystemException(void);
};



/******************************************************************************/
/* PUserException class                                                       */
/******************************************************************************/
class _IMPEXP_PKLIB PUserException : public PException
{
public:
	PUserException(int32 error = P_OK);
	virtual ~PUserException(void);
};

#if __p_os == __p_beos && __POWERPC__
#pragma export off
#endif

#endif
